@@ -349,7 +349,7 @@ void Freshklam::processOutput()
 
     if ((pos = item2.find("daily.cvd is up to date")) != -1){
 	   CollectionDB::instance()->insertEvent("Updates","Database Already Up To Date",dir_combo->url());
-        KNotifyClient::event(kmain->_tray->winId(),"UpdatedDatabase", "Virus Database Up To Date.");
+        KNotifyClient::event(kmain->_tray->winId(),"DatabaseUpToDate", "Virus Database Up To Date.");
         updateMailClient();
     }
 
@@ -477,7 +477,7 @@ void Freshklam::finish()
     kmain->EnableFreshklam->setEnabled(TRUE);
     kmain->DisableFreshklam->setEnabled(FALSE);
 
-    updateMetaDB();
+    //updateMetaDB();
 
 }
 
