@@ -16,6 +16,9 @@ BrowserRun::BrowserRun(Viewer *viewer, QWidget *parent, KParts::ReadOnlyPart *pa
     : KParts::BrowserRun(url, args, part, parent, false, true)
 {
     m_viewer=viewer;
+    connect(m_viewer, SIGNAL(destroyed()), this, SLOT(killMyself()));
+    setEnableExternalBrowser(false);
+
 }
 
 BrowserRun::~BrowserRun()
@@ -31,6 +34,13 @@ void BrowserRun::foundMimeType( const QString & type )
         KParts::BrowserRun::foundMimeType( type );
 }
 
+void BrowserRun::killMyself()
+{
+    kdDebug() << "BrowserRun::killMyself()" << endl;
+    delete this;
+}
+
+
 
 // vim: set et ts=4 sts=4 sw=4:
 #include "klamav_run.moc"
\ No newline at end of file
