@@ -27,7 +27,7 @@
 #include <ktempfile.h>
 #include <ksystemtray.h>
 #include <qtoolbutton.h>
-
+#include <knotifyclient.h>
 
 
 const char *check_desc1[] = {
@@ -291,18 +291,18 @@ void Klamd::processOutput()
 {
 	item2 = "";
 	int pos;
-	
 	if ((pos = (childproc->readln(item2))) != -1) {
+    	kdDebug() << item2 << endl;
 		if ((pos = (item2.find(" FOUND"))) != -1){
 			item2 = item2.stripWhiteSpace();
 			int fnameStartPoint = (item2.find(":") + 1);
 			int fnameEndPoint = item2.findRev(":");
 			QString tmpFName = item2.mid(fnameStartPoint,(fnameEndPoint - fnameStartPoint));
 			QString tmpVirusName = item2.mid((fnameEndPoint+1),(item2.length() - (fnameEndPoint+1)));
-			//kdDebug() << "tmpFName " << tmpFName << endl;
-			//kdDebug() << "tmpVirusName " << tmpVirusName << endl;
 			tmpVirusName.replace("FOUND","");
             CollectionDB::instance()->insertEvent("Virus Found",tmpVirusName,tmpFName);
+            if (recursive_box1->isChecked())
+                KNotifyClient::event(kmain->_tray->winId(),i18n( "ScanCompleteNoVirus" ), i18n( "Virus %1 Found In %2 by Auto-Scan!" ).arg(tmpVirusName).arg(tmpFName));
 			if (recursive_box->isChecked())
 				Quarantine(tmpFName.stripWhiteSpace(),tmpVirusName.stripWhiteSpace());
 		}
